Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2490)

Unified Diff: ash/common/wm/window_state.h

Issue 2778733004: Add WindowPinType property on arua::Window (Closed)
Patch Set: Address review issue Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/wm/window_state.h
diff --git a/ash/common/wm/window_state.h b/ash/common/wm/window_state.h
index 919e6b72e3f2c9b9dae235938cd7467e1c9d41b1..5ac681817ab3be9a1bf766409a1dfa139b9273ac 100644
--- a/ash/common/wm/window_state.h
+++ b/ash/common/wm/window_state.h
@@ -10,6 +10,7 @@
#include "ash/ash_export.h"
#include "ash/common/wm/drag_details.h"
#include "ash/common/wm/wm_types.h"
+#include "ash/public/cpp/window_pin_type.h"
#include "base/gtest_prod_util.h"
#include "base/macros.h"
#include "base/observer_list.h"
@@ -319,6 +320,9 @@ class ASH_EXPORT WindowState {
// Called from the associated WmWindow once the show state changes.
void OnWindowShowStateChanged();
+ // Called from the associated WmWindow once the window pin type changes.
+ void OnWindowPinTypeChanged();
+
protected:
explicit WindowState(WmWindow* window);
@@ -338,6 +342,9 @@ class ASH_EXPORT WindowState {
// Returns the window's current show state.
ui::WindowShowState GetShowState() const;
+ // Return the window's current pin type.
+ WindowPinType GetPinType() const;
+
// Sets the window's bounds in screen coordinates.
void SetBoundsInScreen(const gfx::Rect& bounds_in_screen);
@@ -345,9 +352,10 @@ class ASH_EXPORT WindowState {
// workspace if the window represented by |window_state| is side snapped.
void AdjustSnappedBounds(gfx::Rect* bounds);
// Updates the window show state according to the current window state type.
// Note that this does not update the window bounds.
- void UpdateWindowShowStateFromStateType();
+ void UpdateWindowPropertiesFromStateType();
void NotifyPreStateTypeChange(WindowStateType old_window_state_type);
void NotifyPostStateTypeChange(WindowStateType old_window_state_type);
@@ -345,9 +352,10 @@ class ASH_EXPORT WindowState {
// workspace if the window represented by |window_state| is side snapped.
void AdjustSnappedBounds(gfx::Rect* bounds);
- // Updates the window show state according to the current window state type.
+ // Updates the window properties(show state, pin type) according to the
+ // current window state type.
// Note that this does not update the window bounds.

Powered by Google App Engine
This is Rietveld 408576698